MonteCarloSimulator

Struct MonteCarloSimulator 

pub struct MonteCarloSimulator { /* private fields */ }
Monte Carlo simulator — runs sampling-based simulations.

Implementations

Source

impl MonteCarloSimulator

pub fn new(config: McConfig) -> Self

Create a new simulator.

pub fn simulate<F>( &mut self, distributions: &[Distribution], model: F, ) -> McResult
where F: Fn(&[f64]) -> f64,

Run a simulation with a model function. The model takes a vector of sampled inputs and returns an output.

pub fn compute_stats(samples: &[f64]) -> McResult

Compute statistics from a vector of samples.

pub fn integrate<F>(&mut self, bounds: &[(f64, f64)], f: F) -> McResult
where F: Fn(&[f64]) -> f64,

Estimate the integral of a function over a hyper-rectangle.

pub const fn config(&self) -> &McConfig

Get the config.